Batch Operations
================

.. py:module:: lenskit.batch

The :py:mod:`lenskit.batch` module provides support for applying pipelines to
batches of test data, primarily for offline evaluation.  See :ref:`batch` for
usage instructions.

.. autosummary::
    :toctree:
    :nosignatures:

    ~lenskit.batch.BatchPipelineRunner
    ~lenskit.batch.BatchResults
    ~lenskit.batch.predict
    ~lenskit.batch.recommend


Support Types
-------------

.. autosummary::
    :toctree:
    :nosignatures:

    ~lenskit.batch.InvocationSpec
